@@ -2,7 +2,6 @@ from dagster._core.utils import check_dagster_package_version
 
 from .dagster_job_factory import make_dagster_job_from_airflow_dag
 from .dagster_pipeline_factory import (
-    make_dagster_pipeline_from_airflow_dag,
     make_dagster_repo_from_airflow_dag_bag,
     make_dagster_repo_from_airflow_dags_path,
     make_dagster_repo_from_airflow_example_dags,
@@ -17,7 +16,6 @@ __all__ = [
     "make_airflow_dag",
     "make_airflow_dag_for_operator",
     "make_airflow_dag_containerized",
-    "make_dagster_pipeline_from_airflow_dag",
     "make_dagster_repo_from_airflow_dags_path",
     "make_dagster_repo_from_airflow_dag_bag",
     "make_dagster_job_from_airflow_dag",
