@@ -7,12 +7,12 @@ from dagster_airflow.vendor.docker_operator import DockerOperator
 from docker import APIClient, from_env
 
 import dagster._check as check
-import dagster.seven as seven
-from dagster.core.execution.api import create_execution_plan
-from dagster.core.execution.plan.plan import should_skip_step
-from dagster.core.instance import AIRFLOW_EXECUTION_DATE_STR, DagsterInstance
-from dagster.grpc.types import ExecuteStepArgs
-from dagster.serdes import deserialize_json_to_dagster_namedtuple, serialize_dagster_namedtuple
+import dagster._seven as seven
+from dagster._core.execution.api import create_execution_plan
+from dagster._core.execution.plan.plan import should_skip_step
+from dagster._core.instance import AIRFLOW_EXECUTION_DATE_STR, DagsterInstance
+from dagster._grpc.types import ExecuteStepArgs
+from dagster._serdes import deserialize_json_to_dagster_namedtuple, serialize_dagster_namedtuple
 
 from .util import check_events_for_failures, check_events_for_skips, get_aws_environment
 
@@ -229,6 +229,8 @@ class DagsterDockerOperator(DockerOperator):
         try:
             tags = {AIRFLOW_EXECUTION_DATE_STR: context.get("ts")} if "ts" in context else {}
 
+            recon_pipeline = self.recon_repo.get_reconstructable_pipeline(self.pipeline_name)
+
             pipeline_run = self.instance.register_managed_run(
                 pipeline_name=self.pipeline_name,
                 run_id=self.run_id,
@@ -242,6 +244,7 @@ class DagsterDockerOperator(DockerOperator):
                 pipeline_snapshot=self.pipeline_snapshot,
                 execution_plan_snapshot=self.execution_plan_snapshot,
                 parent_pipeline_snapshot=self.parent_pipeline_snapshot,
+                pipeline_code_origin=recon_pipeline.get_python_origin(),
             )
             if self._should_skip(pipeline_run):
                 raise AirflowSkipException(
